summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Guerry <bzg@altern.org>2013-03-23 17:43:59 +0100
committerBastien Guerry <bzg@altern.org>2013-03-23 17:45:26 +0100
commit2922c1365dd8b22fdf11d9562c7229167d1e76af (patch)
treeefc6d98798bd7369291a396f814bf009ce2b8cec
parentf373bca58b8fe665739815c2b7174dc91e2a9c0c (diff)
downloadorg-mode-2922c1365dd8b22fdf11d9562c7229167d1e76af.tar.gz
testing/lisp/: Use non-obsolete variable names (see previous commit)
* test-org-list.el (test-org-list/cycle-bullet) (test-org-list/move-item-down, test-org-list/move-item-up) (test-org-list/insert-item): Use non-obsolete variable names. * test-org-element.el (test-org-element/at-point): Use `org-list-empty-line-terminates-plain-lists'.
-rw-r--r--testing/lisp/test-org-element.el2
-rw-r--r--testing/lisp/test-org-list.el30
2 files changed, 16 insertions, 16 deletions
diff --git a/testing/lisp/test-org-element.el b/testing/lisp/test-org-element.el
index 1294dc8..f7433d4 100644
--- a/testing/lisp/test-org-element.el
+++ b/testing/lisp/test-org-element.el
@@ -2693,7 +2693,7 @@ Paragraph \\alpha."
(org-test-with-temp-text "- Para1\n\n- Para2"
(progn (forward-line)
(org-element-type
- (let ((org-empty-line-terminates-plain-lists nil))
+ (let ((org-list-empty-line-terminates-plain-lists nil))
(org-element-at-point)))))))
;; Special case: at the last blank line in a plain list, return it
;; instead of the last item.
diff --git a/testing/lisp/test-org-list.el b/testing/lisp/test-org-list.el
index adac82e..39cf481 100644
--- a/testing/lisp/test-org-list.el
+++ b/testing/lisp/test-org-list.el
@@ -174,12 +174,12 @@
(let ((org-plain-list-ordered-item-terminator 41))
(org-cycle-list-bullet)
(buffer-string)))))
;; When `org-alphabetical-lists' is non-nil, cycle to alpha bullets.
(should
(equal "a. item"
(org-test-with-temp-text "1) item"
(let ((org-plain-list-ordered-item-terminator t)
- (org-alphabetical-lists t))
+ (org-list-allow-alphabetical t))
(org-cycle-list-bullet)
(buffer-string)))))
;; Do not cycle to alpha bullets when list has more than 26
@@ -214,7 +214,7 @@
26) item 26
27) item 27"
(let ((org-plain-list-ordered-item-terminator t)
- (org-alphabetical-lists t))
+ (org-list-allow-alphabetical t))
(org-cycle-list-bullet)
(buffer-substring (point) (line-end-position)))))))
@@ -482,7 +482,7 @@
"- item 2\n- item 1\n - sub-item 1")))
;; Preserve blank lines.
(org-test-with-temp-text "- item 1\n\n- item 2"
- (let ((org-empty-line-terminates-plain-lists nil)) (org-move-item-down))
+ (let ((org-list-empty-line-terminates-plain-lists nil)) (org-move-item-down))
(should (equal (buffer-string) "- item 2\n\n- item 1")))
;; Error when trying to move the last item...
(org-test-with-temp-text "- item 1\n- item 2"
@@ -567,7 +567,7 @@
;; Preserve blank lines.
(org-test-with-temp-text "- item 1\n\n- item 2"
(search-forward "- item 2")
- (let ((org-empty-line-terminates-plain-lists nil)) (org-move-item-up))
+ (let ((org-list-empty-line-terminates-plain-lists nil)) (org-move-item-up))
(should (equal (buffer-string) "- item 2\n\n- item 1")))
;; Error when trying to move the first item...
(org-test-with-temp-text "- item 1\n- item 2"
@@ -631,10 +631,10 @@
;; Blank lines specifications.
;;
;; Non-nil `org-blank-before-new-entry': insert a blank line, unless
- ;; `org-empty-line-terminates-plain-lists' is non-nil.
+ ;; `org-list-empty-line-terminates-plain-lists' is non-nil.
(should
(org-test-with-temp-text "- a"
- (let ((org-empty-line-terminates-plain-lists nil)
+ (let ((org-list-empty-line-terminates-plain-lists nil)
(org-blank-before-new-entry '((plain-list-item . t))))
(end-of-line)
(org-insert-item)
@@ -642,7 +642,7 @@
(looking-at "$"))))
(should-not
(org-test-with-temp-text "- a"
- (let ((org-empty-line-terminates-plain-lists t)
+ (let ((org-list-empty-line-terminates-plain-lists t)
(org-blank-before-new-entry '((plain-list-item . t))))
(end-of-line)
(org-insert-item)
@@ -651,7 +651,7 @@
;; Nil `org-blank-before-new-entry': do not insert a blank line.
(should-not
(org-test-with-temp-text "- a"
- (let ((org-empty-line-terminates-plain-lists nil)
+ (let ((org-list-empty-line-terminates-plain-lists nil)
(org-blank-before-new-entry '((plain-list-item . nil))))
(end-of-line)
(org-insert-item)
@@ -661,7 +661,7 @@
;; line already in the sole item, do not insert one.
(should-not
(org-test-with-temp-text "- a"
- (let ((org-empty-line-terminates-plain-lists nil)
+ (let ((org-list-empty-line-terminates-plain-lists nil)
(org-blank-before-new-entry '((plain-list-item . auto))))
(end-of-line)
(org-insert-item)
@@ -671,7 +671,7 @@
;; line in the sole item, insert another one.
(should
(org-test-with-temp-text "- a\n\n b"
- (let ((org-empty-line-terminates-plain-lists nil)
+ (let ((org-list-empty-line-terminates-plain-lists nil)
(org-blank-before-new-entry '((plain-list-item . auto))))
(goto-char (point-max))
(org-insert-item)
@@ -681,7 +681,7 @@
;; a blank line, preserve it.
(should
(org-test-with-temp-text "- a\n\n"
- (let ((org-empty-line-terminates-plain-lists nil)
+ (let ((org-list-empty-line-terminates-plain-lists nil)
(org-blank-before-new-entry '((plain-list-item . auto))))
(goto-char (point-max))
(org-insert-item)
@@ -691,7 +691,7 @@
;; are already separated by blank lines, insert one.
(should
(org-test-with-temp-text "- a\n\n- b"
- (let ((org-empty-line-terminates-plain-lists nil)
+ (let ((org-list-empty-line-terminates-plain-lists nil)
(org-blank-before-new-entry '((plain-list-item . auto))))
(goto-char (point-max))
(org-insert-item)
@@ -699,14 +699,14 @@
(looking-at "$"))))
(should
(org-test-with-temp-text "- a\n\n- b"
- (let ((org-empty-line-terminates-plain-lists nil)
+ (let ((org-list-empty-line-terminates-plain-lists nil)
(org-blank-before-new-entry '((plain-list-item . auto))))
(org-insert-item)
(forward-line)
(looking-at "$"))))
(should
(org-test-with-temp-text "- a\n #+BEGIN_EXAMPLE\n\n x\n #+END_EXAMPLE"
- (let ((org-empty-line-terminates-plain-lists nil)
+ (let ((org-list-empty-line-terminates-plain-lists nil)
(org-blank-before-new-entry '((plain-list-item . auto))))
(goto-char (point-max))
(org-insert-item)
@@ -174,12 +174,12 @@
(org-cycle-list-bullet)
(buffer-string)))))
- ;; When `org-alphabetical-lists' is non-nil, cycle to alpha bullets.
+ ;; When `org-list-allow-alphabetical' is non-nil, cycle to alpha bullets.
(should
(equal "a. item"